package
Version:
v0.2.36
Opens a new window with list of versions in this module.
Published: Feb 20, 2026
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
APIURL string `mapstructure:"api_url"`
FrontendURI string `mapstructure:"frontend_uri"`
AppURLSuffix string `mapstructure:"app_url_suffix"`
AppURLFEOnlySuffix string `mapstructure:"app_url_fe_only_suffix"`
}
Config represents the application configuration
Load initializes and returns the application config
Source Files
¶
Click to show internal directories.
Click to hide internal directories.