token

package
v1.0.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 21, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DeleteDefaultOrg

func DeleteDefaultOrg() error

DeleteDefaultOrg removes the default organization ID from the system keyring

func DeleteGithubUsername added in v0.1.18

func DeleteGithubUsername() error

DeleteGithubUsername removes the GitHub username from the system keyring

func DeleteToken

func DeleteToken() error

deleteToken removes the access token from the system keyring

func GetDefaultOrg

func GetDefaultOrg() (string, string, error)

GetDefaultOrg retrieves the default organization ID from the system keyring

func GetGithubUsername added in v0.1.18

func GetGithubUsername() (string, error)

GetGithubUsername retrieves the GitHub username from the system keyring Returns empty string and nil error if not found

func GetToken

func GetToken() (string, error)

getToken retrieves the access token from the system keyring

func StoreDefaultOrg

func StoreDefaultOrg(orgID string, orgName string) error

StoreDefaultOrg saves the default organization ID to the system keyring

func StoreGithubUsername added in v0.1.18

func StoreGithubUsername(username string) error

StoreGithubUsername saves the GitHub username to the system keyring

func StoreToken

func StoreToken(token string) error

storeToken saves the access token to the system keyring

Types

This section is empty.

Jump to