app

package
v1.0.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 21, 2026 License: MIT Imports: 23 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Cmd = &cobra.Command{
	Use:   "app",
	Short: "Application management commands",
	Long:  `Commands for creating and managing applications.`,
	Args:  utils.NoArgs,
	PersistentPreRunE: middleware.ChainParent(
		middleware.CheckNodeInstalled,
		middleware.CheckNodeVersion("22.12"),
		middleware.CheckPnpmInstalled,
	),
	RunE: func(cmd *cobra.Command, args []string) error {
		cmd.Help()
		return nil
	},
}

Cmd represents the app command

Functions

func RunStartInDir added in v0.2.29

func RunStartInDir(cmd *cobra.Command, dir string) error

RunStartInDir changes to the specified directory and runs pnpm install and pnpm dev. If dir is empty, it uses the current directory.

Types

This section is empty.

Jump to