Documentation
¶
Index ¶
- func DeleteDefaultOrg() error
- func DeleteGithubUsername() error
- func DeleteToken() error
- func GetDefaultOrg() (string, string, error)
- func GetGithubUsername() (string, error)
- func GetToken() (string, error)
- func StoreDefaultOrg(orgID string, orgName string) error
- func StoreGithubUsername(username string) error
- func StoreToken(token string) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DeleteDefaultOrg ¶
func DeleteDefaultOrg() error
DeleteDefaultOrg removes the default organization ID from the system keyring
func DeleteGithubUsername ¶ added in v0.1.18
func DeleteGithubUsername() error
DeleteGithubUsername removes the GitHub username from the system keyring
func DeleteToken ¶
func DeleteToken() error
deleteToken removes the access token from the system keyring
func GetDefaultOrg ¶
GetDefaultOrg retrieves the default organization ID from the system keyring
func GetGithubUsername ¶ added in v0.1.18
GetGithubUsername retrieves the GitHub username from the system keyring Returns empty string and nil error if not found
func StoreDefaultOrg ¶
StoreDefaultOrg saves the default organization ID to the system keyring
func StoreGithubUsername ¶ added in v0.1.18
StoreGithubUsername saves the GitHub username to the system keyring
func StoreToken ¶
storeToken saves the access token to the system keyring
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.