token

package
v0.1.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 5, 2025 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DeleteDefaultOrg

func DeleteDefaultOrg() error

DeleteDefaultOrg removes the default organization ID from the system keyring

func DeleteToken

func DeleteToken() error

deleteToken removes the access token from the system keyring

func GetDefaultOrg

func GetDefaultOrg() (string, string, error)

GetDefaultOrg retrieves the default organization ID from the system keyring

func GetToken

func GetToken() (string, error)

getToken retrieves the access token from the system keyring

func StoreDefaultOrg

func StoreDefaultOrg(orgID string, orgName string) error

StoreDefaultOrg saves the default organization ID to the system keyring

func StoreToken

func StoreToken(token string) error

storeToken saves the access token to the system keyring

Types

This section is empty.

Jump to