Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DeleteDefaultOrg ¶
func DeleteDefaultOrg() error
DeleteDefaultOrg removes the default organization ID from the system keyring
func DeleteToken ¶
func DeleteToken() error
deleteToken removes the access token from the system keyring
func GetDefaultOrg ¶
GetDefaultOrg retrieves the default organization ID from the system keyring
func StoreDefaultOrg ¶
StoreDefaultOrg saves the default organization ID to the system keyring
func StoreToken ¶
storeToken saves the access token to the system keyring
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.