Documentation
¶
Overview ¶
Copyright © 2025 NAME HERE <EMAIL ADDRESS>
Copyright © 2025 NAME HERE <EMAIL ADDRESS>
Copyright © 2025 NAME HERE <EMAIL ADDRESS>
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Cmd = &cobra.Command{ Use: "user", Short: "User management commands", Long: `Commands for managing user authentication and profile.`, Args: utils.NoArgs, Run: func(cmd *cobra.Command, args []string) { cmd.Help() }, }
Cmd represents the user command
Functions ¶
func RunLoginForLink ¶ added in v0.2.29
RunLoginForLink is an exported function that runs the login flow for the link command. It's a simplified version that doesn't print the full success message.
func SelectOrganization ¶
func SelectOrganization(cobraCmd *cobra.Command, orgs []apiClient.Organization) (*apiClient.Organization, error)
SelectOrganization prompts the user to select an organization from the list
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.