Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CheckLogin ¶
CheckLogin checks if the user is logged in and the session is valid
func CheckPnpmInstalled ¶
CheckPnpmInstalled checks if pnpm is installed in the system path
Types ¶
type CommandCheck ¶
CommandCheck is a function that performs a check before a command is run
func CheckNodeVersion ¶
func CheckNodeVersion(minVersion string) CommandCheck
CheckNodeVersion checks if node is installed and meets the minimum version requirement
type MiddlewareError ¶
MiddlewareError is a custom error type that includes a title and suggestion
func (*MiddlewareError) Error ¶
func (e *MiddlewareError) Error() string
func (*MiddlewareError) Unwrap ¶
func (e *MiddlewareError) Unwrap() error
Click to show internal directories.
Click to hide internal directories.